@@ -11,7 +11,7 @@ using System.Collections.Generic;
 namespace NDesk.DBus
 {
 	//yyyyuua{yv}
-	public struct Header
+	struct Header
 	{
 		public EndianFlag Endianness;
 		public MessageType MessageType;
@@ -79,7 +79,7 @@ namespace NDesk.DBus
 	}
 	*/
 
-	public enum MessageType : byte
+	enum MessageType : byte
 	{
 		//This is an invalid type.
 		Invalid,
@@ -93,7 +93,7 @@ namespace NDesk.DBus
 		Signal,
 	}
 
-	public enum FieldCode : byte
+	enum FieldCode : byte
 	{
 		Invalid,
 			Path,
@@ -109,38 +109,53 @@ namespace NDesk.DBus
 #endif
 	}
 
-	public enum EndianFlag : byte
+	enum EndianFlag : byte
 	{
 		Little = (byte)'l',
 		Big = (byte)'B',
 	}
 
 	[Flags]
-	public enum HeaderFlag : byte
+	enum HeaderFlag : byte
 	{
 		None = 0,
 		NoReplyExpected = 0x1,
 		NoAutoStart = 0x2,
 	}
 
-	public struct ObjectPath //: IComparable, IComparable<ObjectPath>, IEquatable<ObjectPath>
+	public class ObjectPath //: IComparable, IComparable<ObjectPath>, IEquatable<ObjectPath>
 	{
 		public static readonly ObjectPath Root = new ObjectPath ("/");
 
-		public readonly string Value;
+		internal readonly string Value;
 
 		public ObjectPath (string value)
 		{
 			this.Value = value;
 		}
 
+		public override bool Equals (object o)
+		{
+			ObjectPath b = o as ObjectPath;
+
+			if (b == null)
+				return false;
+
+			return Value.Equals (b.Value);
+		}
+
+		public override int GetHashCode ()
+		{
+			return Value.GetHashCode ();
+		}
+
 		public override string ToString ()
 		{
 			return Value;
 		}
 
 		//this may or may not prove useful
-		public string[] Decomposed
+		internal string[] Decomposed
 		{
 			get {
 				return Value.Split (new char[] {'/'}, StringSplitOptions.RemoveEmptyEntries);
@@ -151,7 +166,7 @@ namespace NDesk.DBus
 			}
 		}
 
-		public ObjectPath Parent
+		internal ObjectPath Parent
 		{
 			get {
 				if (Value == Root.Value)
@@ -183,7 +198,7 @@ namespace NDesk.DBus
 		*/
 	}
 
-	public static class Protocol
+	static class Protocol
 	{
 		//protocol versions that we support
 		public const byte MinVersion = 0;
